==> dx_4.1.3.orig.tar.gz: dx-4.1.3.orig/src/uipp/dxuilib/sequence.h <==
"//\n",
"// time: Fri Mar 27 08:17:50 1998\n",
"//\n",
"// version: 3.1.2 (format), 4.1.1 (DX Beta)\n",
"//\n",
"//\n",
"// MODULE main\n",
"//\n",
"// comment: This example creates banded colors for a 2 dimensional data set. The interactors allow you to specify the break points of the bands, as well as the set of colors to apply to the bands. \n",
"// page assignment: java seqno	order=2, windowed=0, showing=1\n",
"// workspace: width = 545, height = 520\n",
"// layout: snap = 0, width = 50, height = 50, align = NN\n",
"//\n",
"macro main(\n",
") -> (\n",
") {\n",
"    // \n",
"    // node GetLocal[1]: x = 297, y = 0, inputs = 3, label = GetLocal\n",
"    // input[1]: defaulting = 0, visible = 1, type = 67108863, value = 0\n",
"    // page group: java seqno\n",
"    //\n",
"main_GetLocal_1_out_1,\n",
"main_GetLocal_1_out_2 = \n",
"    GetLocal(\n",
"    main_GetLocal_1_in_1,\n",
"    main_GetLocal_1_in_2,\n",
"    main_GetLocal_1_in_3\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node Compute2[1]: x = 251, y = 88, inputs = 5, label = Compute2\n",
"    // input[1]: defaulting = 0, visible = 1, type = 32, value = \"loop+1\"\n",
"    // input[2]: defaulting = 0, visible = 1, type = 32, value = \"loop\"\n",
"    // input[4]: visible = 0\n",
"    // input[5]: visible = 0\n",
"    // page group: java seqno\n",
"    //\n",
"main_Compute2_1_out_1 = \n",
"    Compute2(\n",
"    main_Compute2_1_in_1,\n",
"    main_Compute2_1_in_2,\n",
"    main_GetLocal_1_out_1,\n",
"    main_Compute2_1_in_4,\n",
"    main_Compute2_1_in_5\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node GetGlobal[1]: x = 137, y = 0, inputs = 3, label = GetGlobal\n",
"    // input[1]: defaulting = 0, visible = 1, type = 67108863, value = 0\n",
"    // page group: java seqno\n",
"    //\n",
"main_GetGlobal_1_out_1,\n",
"main_GetGlobal_1_out_2 = \n",
"    GetGlobal(\n",
"    main_GetGlobal_1_in_1,\n",
"    main_GetGlobal_1_in_2,\n",
"    main_GetGlobal_1_in_3\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node Compute2[2]: x = 72, y = 88, inputs = 5, label = Compute2\n",
"    // input[1]: defaulting = 0, visible = 1, type = 32, value = \"loop+1\"\n",
"    // input[2]: defaulting = 0, visible = 1, type = 32, value = \"loop\"\n",
"    // input[4]: visible = 0\n",
"    // input[5]: visible = 0\n",
"    // page group: java seqno\n",
"    //\n",
"main_Compute2_2_out_1 = \n",
"    Compute2(\n",
"    main_Compute2_2_in_1,\n",
"    main_Compute2_2_in_2,\n",
"    main_GetGlobal_1_out_1,\n",
"    main_Compute2_2_in_4,\n",
"    main_Compute2_2_in_5\n",
"    ) [instance: 2, cache: 1];\n",
"    // \n",
"    // node Compute2[3]: x = 0, y = 198, inputs = 5, label = Compute2\n",
"    // input[1]: defaulting = 0, visible = 1, type = 32, value = \"global-local\"\n",
"    // input[2]: defaulting = 0, visible = 1, type = 32, value = \"local\"\n",
"    // input[4]: defaulting = 0, visible = 1, type = 32, value = \"global\"\n",
"    // page group: java seqno\n",
"    //\n",
"main_Compute2_3_out_1 = \n",
"    Compute2(\n",
"    main_Compute2_3_in_1,\n",
"    main_Compute2_3_in_2,\n",
"    main_Compute2_1_out_1,\n",
"    main_Compute2_3_in_4,\n",
"    main_Compute2_2_out_1\n",
"    ) [instance: 3, cache: 1];\n",
"    // \n",
"    // node Compute[1]: x = 183, y = 350, inputs = 3, label = Compute\n",
"    // input[1]: defaulting = 0, visible = 0, type = 32, value = \"[$0, $1]\"\n",
"    // page group: java seqno\n",
"    // expression: value = [a, b]\n",
"    // name[2]: value = a\n",
"    // name[3]: value = b\n",
"    //\n",
"main_Compute_1_out_1 = \n",
"    Compute(\n",
"    main_Compute_1_in_1,\n",
"    main_Compute2_3_out_1,\n",
"    main_GetLocal_1_out_1\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node DXLInput[1]: x = 452, y = 0, inputs = 1, label = _java_control\n",
"    // input[1]: defaulting = 0, visible = 1, type = 29, value = 0\n",
"    // page group: java seqno\n",
"    //\n",
"    main_DXLInput_1_out_1 = _java_control;\n",
"    // \n",
"    // node SetGlobal[1]: x = 137, y = 199, inputs = 3, label = SetGlobal\n",
"    // page group: java seqno\n",
"    //\n",
"    SetGlobal(\n",
"    main_Compute2_2_out_1,\n",
"    main_GetGlobal_1_out_2,\n",
"    main_SetGlobal_1_in_3\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node SetLocal[1]: x = 298, y = 207, inputs = 3, label = SetLocal\n",
"    // page group: java seqno\n",
"    //\n",
"    SetLocal(\n",
"    main_Compute2_1_out_1,\n",
"    main_GetLocal_1_out_2,\n",
"    main_SetLocal_1_in_3\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node Transmitter[3]: x = 160, y = 458, inputs = 1, label = java_sequence\n",
"    // page group: java seqno\n",
"    //\n",
"java_sequence = main_Compute_1_out_1;\n",
"    // \n",
"    // node Transmitter[4]: x = 455, y = 203, inputs = 1, label = java_control\n",
"    // page group: java seqno\n",
"    //\n",
"java_control = main_DXLInput_1_out_1;\n",
"// network: end of macro body\n",
"}\n",
"main_GetLocal_1_in_1 = 0;\n",
"main_GetLocal_1_in_2 = NULL;\n",
"main_GetLocal_1_in_3 = NULL;\n",
"main_GetLocal_1_out_1 = NULL;\n",
"main_GetLocal_1_out_2 = NULL;\n",
"main_Compute2_1_in_1 = \"loop+1\";\n",
"main_Compute2_1_in_2 = \"loop\";\n",
"main_Compute2_1_in_4 = NULL;\n",
"main_Compute2_1_in_5 = NULL;\n",
"main_Compute2_1_out_1 = NULL;\n",
"main_GetGlobal_1_in_1 = 0;\n",
"main_GetGlobal_1_in_2 = NULL;\n",
"main_GetGlobal_1_in_3 = NULL;\n",
"main_GetGlobal_1_out_1 = NULL;\n",
"main_GetGlobal_1_out_2 = NULL;\n",
"main_Compute2_2_in_1 = \"loop+1\";\n",
"main_Compute2_2_in_2 = \"loop\";\n",
"main_Compute2_2_in_4 = NULL;\n",
"main_Compute2_2_in_5 = NULL;\n",
"main_Compute2_2_out_1 = NULL;\n",
"main_Compute2_3_in_1 = \"global-local\";\n",
"main_Compute2_3_in_2 = \"local\";\n",
"main_Compute2_3_in_4 = \"global\";\n",
"main_Compute2_3_out_1 = NULL;\n",
"main_Compute_1_in_1 = \"[$0, $1]\";\n",
"main_Compute_1_out_1 = NULL;\n",
"_java_control = 0;\n",
"main_SetGlobal_1_in_3 = NULL;\n",
"main_SetLocal_1_in_3 = NULL;\n",
"Executive(\"product version 4 1 1\");\n",
"$sync\n",
"// This network contains DXLink tools.  Therefore, the following line(s)\n",
"// that would cause an execution when run in script mode have been \n",
"// commented out.  This will facilitate the use of the DXLink routines\n",
"// exDXLLoadScript() and DXLLoadVisualProgram() when the DXLink\n",
"// application is connected to an executive.\n",
"// main();\n",
NULL

==> dx_4.4.4.orig.tar.gz: dx-4.4.4/src/uipp/dxuilib/sequence.h <==
"//\n",
"// time: Wed Mar  5 11:15:47 2003\n",
"//\n",
"// version: 3.2.0 (format), 4.2.0 (DX)\n",
"//\n",
"//\n",
"// MODULE main\n",
"//\n",
"// comment: This example creates banded colors for a 2 dimensional data set. The interactors allow you to specify the break points of the bands, as well as the set of colors to apply to the bands. \n",
"// page assignment: java seqno	order=2, windowed=0, showing=1\n",
"// workspace: width = 565, height = 522\n",
"// layout: snap = 0, width = 50, height = 50, align = NN\n",
"//\n",
"macro main(\n",
") -> (\n",
") {\n",
"    // \n",
"    // node GetLocal[1]: x = 166, y = 10, inputs = 3, label = GetLocal\n",
"    // input[1]: defaulting = 0, visible = 1, type = 67108863, value = 0\n",
"    // page group: java seqno\n",
"    //\n",
"main_GetLocal_1_out_1,\n",
"main_GetLocal_1_out_2 = \n",
"    GetLocal(\n",
"    main_GetLocal_1_in_1,\n",
"    main_GetLocal_1_in_2,\n",
"    main_GetLocal_1_in_3\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node Compute2[1]: x = 10, y = 190, inputs = 5, label = Compute2\n",
"    // input[1]: defaulting = 0, visible = 1, type = 32, value = \"loop+1\"\n",
"    // input[2]: defaulting = 0, visible = 1, type = 32, value = \"loop\"\n",
"    // input[4]: visible = 0\n",
"    // input[5]: visible = 0\n",
"    // page group: java seqno\n",
"    //\n",
"main_Compute2_1_out_1 = \n",
"    Compute2(\n",
"    main_Compute2_1_in_1,\n",
"    main_Compute2_1_in_2,\n",
"    main_GetLocal_1_out_1,\n",
"    main_Compute2_1_in_4,\n",
"    main_Compute2_1_in_5\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node GetGlobal[1]: x = 248, y = 100, inputs = 3, label = GetGlobal\n",
"    // input[1]: defaulting = 0, visible = 1, type = 67108863, value = 0\n",
"    // page group: java seqno\n",
"    //\n",
"main_GetGlobal_1_out_1,\n",
"main_GetGlobal_1_out_2 = \n",
"    GetGlobal(\n",
"    main_GetGlobal_1_in_1,\n",
"    main_GetGlobal_1_in_2,\n",
"    main_GetGlobal_1_in_3\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node Compute2[2]: x = 102, y = 190, inputs = 5, label = Compute2\n",
"    // input[1]: defaulting = 0, visible = 1, type = 32, value = \"loop+1\"\n",
"    // input[2]: defaulting = 0, visible = 1, type = 32, value = \"loop\"\n",
"    // input[4]: visible = 0\n",
"    // input[5]: visible = 0\n",
"    // page group: java seqno\n",
"    //\n",
"main_Compute2_2_out_1 = \n",
"    Compute2(\n",
"    main_Compute2_2_in_1,\n",
"    main_Compute2_2_in_2,\n",
"    main_GetGlobal_1_out_1,\n",
"    main_Compute2_2_in_4,\n",
"    main_Compute2_2_in_5\n",
"    ) [instance: 2, cache: 1];\n",
"    // \n",
"    // node Compute2[3]: x = 32, y = 280, inputs = 5, label = Compute2\n",
"    // input[1]: defaulting = 0, visible = 1, type = 32, value = \"global-local\"\n",
"    // input[2]: defaulting = 0, visible = 1, type = 32, value = \"local\"\n",
"    // input[4]: defaulting = 0, visible = 1, type = 32, value = \"global\"\n",
"    // page group: java seqno\n",
"    //\n",
"main_Compute2_3_out_1 = \n",
"    Compute2(\n",
"    main_Compute2_3_in_1,\n",
"    main_Compute2_3_in_2,\n",
"    main_Compute2_1_out_1,\n",
"    main_Compute2_3_in_4,\n",
"    main_Compute2_2_out_1\n",
"    ) [instance: 3, cache: 1];\n",
"    // \n",
"    // node Compute[1]: x = 75, y = 370, inputs = 3, label = Compute\n",
"    // input[1]: defaulting = 0, visible = 0, type = 32, value = \"[$0, $1]\"\n",
"    // page group: java seqno\n",
"    // expression: value = [a, b]\n",
"    // name[2]: value = a\n",
"    // name[3]: value = b\n",
"    //\n",
"main_Compute_1_out_1 = \n",
"    Compute(\n",
"    main_Compute_1_in_1,\n",
"    main_Compute2_3_out_1,\n",
"    main_GetLocal_1_out_1\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node DXLInput[1]: x = 353, y = 10, inputs = 1, label = _java_control\n",
"    // input[1]: defaulting = 0, visible = 1, type = 29, value = 0\n",
"    // page group: java seqno\n",
"    //\n",
"    main_DXLInput_1_out_1 = _java_control;\n",
"    // \n",
"    // node SetGlobal[1]: x = 249, y = 280, inputs = 3, label = SetGlobal\n",
"    // page group: java seqno\n",
"    //\n",
"    SetGlobal(\n",
"    main_Compute2_2_out_1,\n",
"    main_GetGlobal_1_out_2,\n",
"    main_SetGlobal_1_in_3\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node SetLocal[1]: x = 167, y = 280, inputs = 3, label = SetLocal\n",
"    // page group: java seqno\n",
"    //\n",
"    SetLocal(\n",
"    main_Compute2_1_out_1,\n",
"    main_GetLocal_1_out_2,\n",
"    main_SetLocal_1_in_3\n",
"    ) [instance: 1, cache: 1];\n",
"    // \n",
"    // node Transmitter[3]: x = 57, y = 460, inputs = 1, label = java_sequence\n",
"    // page group: java seqno\n",
"    //\n",
"java_sequence = main_Compute_1_out_1;\n",
"    // \n",
"    // node Transmitter[4]: x = 356, y = 100, inputs = 1, label = java_control\n",
"    // page group: java seqno\n",
"    //\n",
"java_control = main_DXLInput_1_out_1;\n",
"    //\n",
"    // decorator Annotate	pos=(330,206) size=235x40 style(Label), value = <NULL>\n",
"    // annotation user_begin: 58\n",
"    // annotation user: D O   N O T   E D I T\n",
"    // annotation user: This page was created automatically.\n",
"    // annotation user_end: <NULL>\n",
"    // page group: java seqno\n",
"// network: end of macro body\n",
"}\n",
"main_GetLocal_1_in_1 = 0;\n",
"main_GetLocal_1_in_2 = NULL;\n",
"main_GetLocal_1_in_3 = NULL;\n",
"main_GetLocal_1_out_1 = NULL;\n",
"main_GetLocal_1_out_2 = NULL;\n",
"main_Compute2_1_in_1 = \"loop+1\";\n",
"main_Compute2_1_in_2 = \"loop\";\n",
"main_Compute2_1_in_4 = NULL;\n",
"main_Compute2_1_in_5 = NULL;\n",
"main_Compute2_1_out_1 = NULL;\n",
"main_GetGlobal_1_in_1 = 0;\n",
"main_GetGlobal_1_in_2 = NULL;\n",
"main_GetGlobal_1_in_3 = NULL;\n",
"main_GetGlobal_1_out_1 = NULL;\n",
"main_GetGlobal_1_out_2 = NULL;\n",
"main_Compute2_2_in_1 = \"loop+1\";\n",
"main_Compute2_2_in_2 = \"loop\";\n",
"main_Compute2_2_in_4 = NULL;\n",
"main_Compute2_2_in_5 = NULL;\n",
"main_Compute2_2_out_1 = NULL;\n",
"main_Compute2_3_in_1 = \"global-local\";\n",
"main_Compute2_3_in_2 = \"local\";\n",
"main_Compute2_3_in_4 = \"global\";\n",
"main_Compute2_3_out_1 = NULL;\n",
"main_Compute_1_in_1 = \"[$0, $1]\";\n",
"main_Compute_1_out_1 = NULL;\n",
"_java_control = 0;\n",
"main_SetGlobal_1_in_3 = NULL;\n",
"main_SetLocal_1_in_3 = NULL;\n",
"Executive(\"product version 4 2 0\");\n",
"$sync\n",
"// This network contains DXLink tools.  Therefore, the following line(s)\n",
"// that would cause an execution when run in script mode have been \n",
"// commented out.  This will facilitate the use of the DXLink routines\n",
"// exDXLLoadScript() and DXLLoadVisualProgram() when the DXLink\n",
"// application is connected to an executive.\n",
"// main();\n",
NULL
